@@ -42,67 +42,70 @@ class TestParser(unittest.TestCase):
         function = sp.Function('Tensor')(sp.Symbol('TUU'), sp.Symbol('mu'), sp.Symbol('nu'))
         self.assertEqual(
             nl.Parser._generate_covdrv(function, 'beta'),
-            r'\nabla_{\beta} T^{\mu \nu} = \partial_{\beta} T^{\mu \nu} + \text{Gamma}^{\mu}_{a \beta} (T^{a \nu}) + \text{Gamma}^{\nu}_{a \beta} (T^{\mu a})'
+            r'\nabla_{\beta} T^{\mu \nu} = \partial_{\beta} T^{\mu \nu} + \text{Gamma}^{\mu}_{i_1 \beta} (T^{i_1 \nu}) + \text{Gamma}^{\nu}_{i_1 \beta} (T^{\mu i_1})'
         )
         function = sp.Function('Tensor')(sp.Symbol('TUD'), sp.Symbol('mu'), sp.Symbol('nu'))
         self.assertEqual(
             nl.Parser._generate_covdrv(function, 'beta'),
-            r'\nabla_{\beta} T^{\mu}_{\nu} = \partial_{\beta} T^{\mu}_{\nu} + \text{Gamma}^{\mu}_{a \beta} (T^{a}_{\nu}) - \text{Gamma}^{a}_{\nu \beta} (T^{\mu}_{a})'
+            r'\nabla_{\beta} T^{\mu}_{\nu} = \partial_{\beta} T^{\mu}_{\nu} + \text{Gamma}^{\mu}_{i_1 \beta} (T^{i_1}_{\nu}) - \text{Gamma}^{i_1}_{\nu \beta} (T^{\mu}_{i_1})'
         )
         function = sp.Function('Tensor')(sp.Symbol('TDD'), sp.Symbol('mu'), sp.Symbol('nu'))
         self.assertEqual(
             nl.Parser._generate_covdrv(function, 'beta'),
-            r'\nabla_{\beta} T_{\mu \nu} = \partial_{\beta} T_{\mu \nu} - \text{Gamma}^{a}_{\mu \beta} (T_{a \nu}) - \text{Gamma}^{a}_{\nu \beta} (T_{\mu a})'
+            r'\nabla_{\beta} T_{\mu \nu} = \partial_{\beta} T_{\mu \nu} - \text{Gamma}^{i_1}_{\mu \beta} (T_{i_1 \nu}) - \text{Gamma}^{i_1}_{\nu \beta} (T_{\mu i_1})'
         )
 
     def test_expression_5(self):
         parse_latex(r"""
-            % vardef -diff_type=dD -metric gDD::4D
-            % vardef -diff_type=dD vU::4D
+            % define gDD --dim 4 --deriv dD --metric
+            % define vU --dim 4 --deriv dD
+            % index b --dim 4
             T^\mu_b = \nabla_b v^\mu
         """)
         function = sp.Function('Tensor')(sp.Symbol('vU_cdD'), sp.Symbol('mu'), sp.Symbol('b'))
         self.assertEqual(
             nl.Parser._generate_covdrv(function, 'a'),
-            r'\nabla_{a} \nabla_{b} v^{\mu} = \partial_{a} \nabla_{b} v^{\mu} + \text{Gamma}^{\mu}_{c a} (\nabla_{b} v^{c}) - \text{Gamma}^{c}_{b a} (\nabla_{c} v^{\mu})'
+            r'\nabla_{a} \nabla_{b} v^{\mu} = \partial_{a} \nabla_{b} v^{\mu} + \text{Gamma}^{\mu}_{i_1 a} (\nabla_{b} v^{i_1}) - \text{Gamma}^{i_1}_{b a} (\nabla_{i_1} v^{\mu})'
         )
 
     def test_expression_6(self):
         function = sp.Function('Tensor')(sp.Symbol('g'))
         self.assertEqual(
             nl.Parser._generate_liedrv(function, 'beta', 2),
-            r'\mathcal{L}_\text{beta} g = \text{beta}^{a} \partial_{a} g + (2)(\partial_{a} \text{beta}^{a}) g'
+            r'\mathcal{L}_\text{beta} g = \text{beta}^{i_1} \partial_{i_1} g + (2)(\partial_{i_1} \text{beta}^{i_1}) g'
         )
         function = sp.Function('Tensor')(sp.Symbol('gUU'), sp.Symbol('i'), sp.Symbol('j'))
         self.assertEqual(
             nl.Parser._generate_liedrv(function, 'beta'),
-            r'\mathcal{L}_\text{beta} g^{i j} = \text{beta}^{a} \partial_{a} g^{i j} - (\partial_{a} \text{beta}^{i}) g^{a j} - (\partial_{a} \text{beta}^{j}) g^{i a}'
+            r'\mathcal{L}_\text{beta} g^{i j} = \text{beta}^{i_1} \partial_{i_1} g^{i j} - (\partial_{i_1} \text{beta}^{i}) g^{i_1 j} - (\partial_{i_1} \text{beta}^{j}) g^{i i_1}'
         )
         function = sp.Function('Tensor')(sp.Symbol('gUD'), sp.Symbol('i'), sp.Symbol('j'))
         self.assertEqual(
             nl.Parser._generate_liedrv(function, 'beta'),
-            r'\mathcal{L}_\text{beta} g^{i}_{j} = \text{beta}^{a} \partial_{a} g^{i}_{j} - (\partial_{a} \text{beta}^{i}) g^{a}_{j} + (\partial_{j} \text{beta}^{a}) g^{i}_{a}'
+            r'\mathcal{L}_\text{beta} g^{i}_{j} = \text{beta}^{i_1} \partial_{i_1} g^{i}_{j} - (\partial_{i_1} \text{beta}^{i}) g^{i_1}_{j} + (\partial_{j} \text{beta}^{i_1}) g^{i}_{i_1}'
         )
         function = sp.Function('Tensor')(sp.Symbol('gDD'), sp.Symbol('i'), sp.Symbol('j'))
         self.assertEqual(
             nl.Parser._generate_liedrv(function, 'beta'),
-            r'\mathcal{L}_\text{beta} g_{i j} = \text{beta}^{a} \partial_{a} g_{i j} + (\partial_{i} \text{beta}^{a}) g_{a j} + (\partial_{j} \text{beta}^{a}) g_{i a}'
+            r'\mathcal{L}_\text{beta} g_{i j} = \text{beta}^{i_1} \partial_{i_1} g_{i j} + (\partial_{i} \text{beta}^{i_1}) g_{i_1 j} + (\partial_{j} \text{beta}^{i_1}) g_{i i_1}'
         )
 
     def test_srepl_macro(self):
         nl.parse_latex(r"""
-            % srepl -persist "<1>'" -> "\text{<1>prime}"
-            % srepl -persist "\text{<1..>}_<2>" -> "\text{(<1..>)<2>}"
-            % srepl -persist "<1>_{<2>}" -> "<1>_<2>", "<1>_<2>" -> "\text{<1>_<2>}"
-            % srepl -persist "\text{(<1..>)<2>}" -> "\text{<1..>_<2>}"
-            % srepl -persist "<1>^{<2>}" -> "<1>^<2>", "<1>^<2>" -> "<1>^{{<2>}}"
+            % srepl "<1>'" -> "\text{<1>prime}" --persist
+            % srepl "\text{<1..>}_<2>" -> "\text{(<1..>)<2>}" --persist
+            % srepl "<1>_{<2>}" -> "<1>_<2>" --persist
+            % srepl "<1>_<2>" -> "\text{<1>_<2>}" --persist
+            % srepl "\text{(<1..>)<2>}" -> "\text{<1..>_<2>}" --persist
+            % srepl "<1>^{<2>}" -> "<1>^<2>" --persist
+            % srepl "<1>^<2>" -> "<1>^{{<2>}}" --persist
         """)
         expr = r"x_n^4 + x'_n \exp(x_n y_n^2)"
         self.assertEqual(
             str(nl.parse_latex(expr)),
             "x_n**4 + xprime_n*exp(x_n*y_n**2)"
         )
-        parse_latex(r""" % srepl -persist "<1>'^{<2..>}" -> "\text{<1>prime}" """)
+        parse_latex(r""" % srepl "<1>'^{<2..>}" -> "\text{<1>prime}" --persist """)
         expr = r"v'^{label}"
         self.assertEqual(
             str(nl.parse_latex(expr)),
@@ -112,8 +115,8 @@ class TestParser(unittest.TestCase):
     def test_assignment_1(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -diff_type=dD vU::2D, wU::2D
-                % attrib index [a-z]::2D
+                % define vU wU --dim 2 --deriv dD
+                % index [a-z] --dim 2
                 T^{ab}_c = \partial_c (v^a w^b)
             """)),
             {'vU', 'wU', 'vU_dD', 'wU_dD', 'TUUD'}
@@ -125,23 +128,24 @@ class TestParser(unittest.TestCase):
     def test_assignment_2(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -const w
-                % vardef -diff_type=dD vU::2D
-                % attrib index [a-z]::2D
-                T^a_c = \partial_c (v^a w)
+                % define vU --dim 2 --deriv dD
+                % define w --const
+                % index [a-z] --dim 2
+                T^a_c = % deriv dupD
+                \partial_c (v^a w)
             """)),
-            {'w', 'vU', 'vU_dD', 'TUD'}
+            {'w', 'vU', 'vU_dupD', 'TUD'}
         )
         self.assertEqual(str(TUD),
-            '[[vU_dD00*w, vU_dD01*w], [vU_dD10*w, vU_dD11*w]]'
+            '[[vU_dupD00*w, vU_dupD01*w], [vU_dupD10*w, vU_dupD11*w]]'
         )
 
     def test_assignment_3(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -diff_type=dD -metric gDD::4D
-                % vardef -diff_type=dD vU::4D
-                % attrib index [a-z]::4D
+                % define gDD --dim 4 --deriv dD --metric
+                % define vU --dim 4 --deriv dD
+                % index [a-z] --dim 4
                 T^{ab} = \nabla^b v^a
             """)),
             {'gUU', 'gdet', 'epsilonUUUU', 'gDD', 'vU', 'vU_dD', 'gDD_dD', 'GammaUDD', 'vU_cdD', 'vU_cdU', 'TUU'}
@@ -150,13 +154,13 @@ class TestParser(unittest.TestCase):
     def test_assignment_4(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % attrib coord [x, y]
-                % vardef uD::2D, wD::2D
-                % attrib index [a-z]::2D
+                % coord [x, y]
+                % define uD wD --dim 2
+                % index [a-z] --dim 2
                 u_x = x^2 + 2x \\
                 u_y = y\sqrt{x} \\
                 v_a = u_a + w_a \\
-                % assign -diff_type=dD wD, vD
+                % assign wD vD --deriv dD
                 T_{ab} = \partial_b v_a
             """)),
             {'x', 'y', 'uD', 'wD', 'vD', 'vD_dD', 'wD_dD', 'TDD'}
@@ -168,27 +172,9 @@ class TestParser(unittest.TestCase):
     def test_assignment_5(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % attrib coord [x, y]
-                % vardef uD::2D, wD::2D
-                % assign -diff_type=symbolic uD
-                % attrib index [a-z]::2D
-                u_x = x^2 + 2x \\
-                u_y = y\sqrt{x} \\
-                v_a = u_a + w_a \\
-                T_{bc} = \vphantom{dD} \partial_c v_b
-            """)),
-            {'x', 'y', 'uD', 'wD', 'vD', 'vD_dD', 'wD_dD', 'TDD'}
-        )
-        self.assertEqual(str(TDD),
-            '[[wD_dD00 + 2*x + 2, wD_dD01], [wD_dD10 + y/(2*sqrt(x)), wD_dD11 + sqrt(x)]]'
-        )
-
-    def test_assignment_6(self):
-        self.assertEqual(
-            set(parse_latex(r"""
-                    % vardef vD::2D, uD::2D, wD::2D
-                    % attrib index [a-z]::2D
-                    T_{abc} = \vphantom{dD} ((v_a + u_a)_{,b} - w_{a,b})_{,c}
+                    % define vD uD wD --dim 2 --deriv dD
+                    % index [a-z] --dim 2
+                    T_{abc} = ((v_a + u_a)_{,b} - w_{a,b})_{,c}
             """)),
             {'vD', 'uD', 'wD', 'TDDD', 'uD_dD', 'vD_dD', 'wD_dD', 'wD_dDD', 'uD_dDD', 'vD_dDD'}
         )
@@ -196,17 +182,18 @@ class TestParser(unittest.TestCase):
             'uD_dDD000 + vD_dDD000 - wD_dDD000'
         )
 
-    def test_assignment_7(self):
+    def test_assignment_6(self):
         parse_latex(r"""
-            % attrib coord [\theta, \phi]
-            % vardef -zero gDD::2D
-            % vardef -const r
-            % attrib index [a-z]::2D
+            % coord [\theta, \phi]
+            % define gDD --dim 2 --zero
+            % define r --const
+            % index [a-z] --dim 2
+            % ignore "\begin{align*}" "\end{align*}"
             \begin{align*}
                 g_{0 0} &= r^2 \\
                 g_{1 1} &= r^2 \sin^2(\theta)
             \end{align*}
-            % assign -metric gDD
+            % assign gDD --metric
             \begin{align*}
                 R^\alpha_{\beta\mu\nu} &= \partial_\mu \Gamma^\alpha_{\beta\nu} - \partial_\nu \Gamma^\alpha_{\beta\mu} + \Gamma^\alpha_{\mu\gamma}\Gamma^\gamma_{\beta\nu} - \Gamma^\alpha_{\nu\sigma}\Gamma^\sigma_{\beta\mu} \\
                 R_{\alpha\beta\mu\nu} &= g_{\alpha a} R^a_{\beta\mu\nu} \\
@@ -235,10 +222,10 @@ class TestParser(unittest.TestCase):
             '2/r**2'
         )
 
-    def test_assignment_8(self):
+    def test_assignment_7(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -symmetry=sym01 gDD::4D
+                % define gDD --dim 4 --sym sym01
                 \gamma_{ij} = g_{ij}
             """)),
             {'gDD', 'gammaDD'}
@@ -247,13 +234,13 @@ class TestParser(unittest.TestCase):
             '[[gDD11, gDD12, gDD13], [gDD12, gDD22, gDD23], [gDD13, gDD23, gDD33]]'
         )
 
-    def test_assignment_9(self):
+    def test_assignment_8(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef TUU::3D
-                % vardef vD::2D
-                % attrib index i::2D
-                w^\mu = T^{\mu i} v_i
+                % define TUU --dim 3
+                % define vD --dim 2
+                % index i --dim 2
+                w^a = T^{a i} v_i
             """)),
             {'TUU', 'vD', 'wU'}
         )
@@ -261,20 +248,20 @@ class TestParser(unittest.TestCase):
             '[TUU01*vD0 + TUU02*vD1, TUU11*vD0 + TUU12*vD1, TUU21*vD0 + TUU22*vD1]'
         )
 
-    def test_assignment_10(self):
+    def test_assignment_9(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -metric gDD
-                % vardef ADDD, AUUU
+                % define gDD --dim 3 --metric
+                % define ADDD AUUU --dim 3
                 B^{a b}_c = A^{a b}_c
             """)),
             {'gDD', 'epsilonUUU', 'gdet', 'gUU', 'GammaUDD', 'ADDD', 'AUUU', 'AUUD', 'BUUD'}
         )
 
-    def test_assignment_11(self):
+    def test_assignment_10(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef vD
+                % define vD --dim 3
                 w = v_{x_2}
             """)),
             {'vD', 'w'}
@@ -283,11 +270,11 @@ class TestParser(unittest.TestCase):
             'vD2'
         )
 
-    def test_assignment_12(self):
+    def test_assignment_11(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % attrib coord [x, y, z]
-                % vardef -zero vD
+                % coord [x, y, z]
+                % define vD --dim 3 --zero
                 v_z = y^2 + 2y \\
                 w = v_{x_2}
             """)),
@@ -297,23 +284,48 @@ class TestParser(unittest.TestCase):
             'y**2 + 2*y'
         )
 
+    def test_assignment_12(self):
+        self.assertEqual(
+            set(parse_latex(r"""
+                % define deltaDD --dim 3 --kron
+                % \hat{\gamma}_{ij} = \delta_{ij}
+                % assign gammahatDD --metric
+                % define hDD --dim 3 --deriv dD --sym sym01
+                % \bar{\gamma}_{ij} = h_{ij} + \hat{\gamma}_{ij}
+                % assign gammabarDD --deriv dD --metric
+            """)),
+            {'gammabardet', 'GammabarUDD', 'gammabarDD', 'gammabarDD_dD', 'gammahatdet', 'hDD', 'GammahatUDD', 'hDD_dD', 'gammahatUU', 'deltaDD', 'gammabarUU', 'epsilonUUU', 'gammahatDD'}
+        )
+
     def test_assignment_13(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -kron deltaDD
-                % parse \hat{\gamma}_{ij} = \delta_{ij} \\
-                % assign -diff_type=symbolic -metric gammahatDD
-                % vardef -diff_type=dD -symmetry=sym01 hDD
-                % parse \bar{\gamma}_{ij} = h_{ij} + \hat{\gamma}_{ij} \\
-                % assign -diff_type=dD -metric gammabarDD
+                % coord [r, \theta, \phi]
+                % define vD --dim 3
+                % v_0 = 1
+                % v_1 = r
+                % v_2 = r \sin \theta
+                % R_{ij} = v_i v_j
+                % define gammahatDD --dim 3 --zero
+                % \hat{\gamma}_{ii} = R_{ii} % noimpsum
+                % define hDD --dim 3 --deriv dD
+                % \bar{\gamma}_{ij} = h_{ij} R_{ij} + \hat{\gamma}_{ij} % noimpsum
+                % assign gammabarDD --deriv dD
+                T_{ijk} = \partial_k \bar{\gamma}_{ij}
             """)),
-            {'gammabardet', 'GammabarUDD', 'gammabarDD', 'gammabarDD_dD', 'gammahatdet', 'hDD', 'GammahatUDD', 'hDD_dD', 'gammahatUU', 'deltaDD', 'gammabarUU', 'epsilonUUU', 'gammahatDD'}
+            {'gammabarDD_dD', 'RDD', 'r', 'vD', 'theta', 'gammahatDD', 'TDDD', 'hDD', 'gammabarDD', 'hDD_dD'}
+        )
+        self.assertEqual(str(gammahatDD),
+            '[[1, 0, 0], [0, r**2, 0], [0, 0, r**2*sin(theta)**2]]'
+        )
+        self.assertEqual(str(TDDD[0][-1]),
+            '[hDD02*sin(theta) + hDD_dD020*r*sin(theta), hDD02*r*cos(theta) + hDD_dD021*r*sin(theta), hDD_dD022*r*sin(theta)]'
         )
 
     def test_example_1(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef hUD::4D
+                % define hUD --dim 4
                 h = h^\mu{}_\mu
             """)),
             {'hUD', 'h'}
@@ -325,8 +337,8 @@ class TestParser(unittest.TestCase):
     def test_example_2(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -metric gUU::3D
-                % vardef vD::3D
+                % define gUU --dim 3 --metric
+                % define vD --dim 3
                 v^\mu = g^{\mu\nu} v_\nu
             """)),
             {'gUU', 'epsilonDDD', 'gdet', 'gDD', 'GammaUDD', 'vD', 'vU'}
@@ -338,7 +350,7 @@ class TestParser(unittest.TestCase):
     def test_example_3(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef vU::3D, wU::3D
+                % define vU wU --dim 3
                 u_i = \epsilon_{ijk} v^j w^k
             """)),
             {'epsilonDDD', 'vU', 'wU', 'uD'}
@@ -350,27 +362,27 @@ class TestParser(unittest.TestCase):
     def test_example_4(self):
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -diff_type=dD -symmetry=anti01 FUU::4D
-                % vardef -diff_type=dD -metric gDD::4D
-                % vardef -const k
+                % define FUU --dim 4 --deriv dD --sym anti01
+                % define gDD --dim 4 --deriv dD --metric
+                % define k --const
                 J^\mu = (4\pi k)^{-1} F^{\mu\nu}_{;\nu}
             """)),
             {'FUU', 'gUU', 'gdet', 'epsilonUUUU', 'gDD', 'k', 'FUU_dD', 'gDD_dD', 'GammaUDD', 'FUU_cdD', 'JU'}
         )
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -diff_type=dD -symmetry=anti01 FUU::4D
-                % vardef -diff_type=dD -metric gDD::4D
-                % vardef -const k
+                % define FUU --dim 4 --deriv dD --sym anti01
+                % define gDD --dim 4 --deriv dD --metric
+                % define k --const
                 J^\mu = (4\pi k)^{-1} \nabla_\nu F^{\mu\nu}
             """)),
             {'FUU', 'gUU', 'gdet', 'epsilonUUUU', 'gDD', 'k', 'FUU_dD', 'gDD_dD', 'GammaUDD', 'FUU_cdD', 'JU'}
         )
         self.assertEqual(
             set(parse_latex(r"""
-                % vardef -diff_type=dD -symmetry=anti01 FUU::4D
-                % vardef -diff_type=dD -metric ghatDD::4D
-                % vardef -const k
+                % define FUU --dim 4 --deriv dD --sym anti01
+                % define ghatDD --dim 4 --deriv dD --metric
+                % define k --const
                 J^\mu = (4\pi k)^{-1} \hat{\nabla}_\nu F^{\mu\nu}
             """)),
             {'FUU', 'ghatUU', 'ghatdet', 'epsilonUUUU', 'k',  'ghatDD', 'FUU_dD', 'ghatDD_dD', 'GammahatUDD', 'FUU_cdhatD', 'JU'}
@@ -378,16 +390,17 @@ class TestParser(unittest.TestCase):
 
     def test_example_5_1(self):
         nl.parse_latex(r"""
-            % attrib coord [t, r, \theta, \phi]
-            % vardef -zero gDD::4D
-            % vardef -const G, M
+            % coord [t, r, \theta, \phi]
+            % define gDD --dim 4 --zero
+            % define G M --const
+            % ignore "\begin{align}" "\end{align}"
             \begin{align}
                 g_{t t} &= -\left(1 - \frac{2GM}{r}\right) \\
                 g_{r r} &=  \left(1 - \frac{2GM}{r}\right)^{-1} \\
                 g_{\theta \theta} &= r^2 \\
                 g_{\phi \phi} &= r^2 \sin^2\theta
             \end{align}
-            % assign -metric gDD
+            % assign gDD --metric
         """, ignore_warning=True)
         self.assertEqual(str(gDD[0][0]),
             '2*G*M/r - 1'
@@ -454,10 +467,10 @@ class TestParser(unittest.TestCase):
     @staticmethod
     def test_example_6_1():
         nl.parse_latex(r"""
-            % attrib coord [r, \theta, \phi]
+            % coord [r, \theta, \phi]
             \begin{align}
                 \gamma_{ij} &= g_{ij} \\
-                % assign -metric gammaDD
+                % assign gammaDD --metric
                 \beta_i &= g_{0 i} \\
                 \alpha &= \sqrt{\gamma^{ij}\beta_i\beta_j - g_{0 0}} \\
                 K_{ij} &= \frac{1}{2\alpha}\left(\nabla_i \beta_j + \nabla_j \beta_i\right) \\
@@ -486,18 +499,18 @@ class TestParser(unittest.TestCase):
     @staticmethod
     def test_metric_symmetry():
         parse_latex(r"""
-            % vardef -zero gDD
+            % define gDD --dim 3 --zero
             g_{1 0} = 1 \\
             g_{2 0} = 2
-            % assign -metric gDD
+            % assign gDD --metric
         """)
         assert_equal(gDD[0][1], 1, suppress_message=True)
         assert_equal(gDD[0][2], 2, suppress_message=True)
         parse_latex(r"""
-            % vardef -zero gDD
+            % define gDD --dim 3 --zero
             g_{0 1} = 1 \\
             g_{0 2} = 2
-            % assign -metric gDD
+            % assign gDD --metric
         """)
         assert_equal(gDD[1][0], 1, suppress_message=True)
         assert_equal(gDD[2][0], 2, suppress_message=True)
@@ -506,7 +519,8 @@ class TestParser(unittest.TestCase):
     def test_metric_inverse():
         for DIM in range(2, 5):
             parse_latex(r"""
-                % vardef -metric gDD::{DIM}D
+                % define gDD --dim {DIM} --metric
+                % index [a-c] --dim {DIM}
                 \Delta^a_c = g^{{ab}} g_{{bc}}
             """.format(DIM=DIM))
             for i in range(DIM):
@@ -515,7 +529,8 @@ class TestParser(unittest.TestCase):
                     assert_equal(DeltaUD[i][j], value, suppress_message=True)
         for DIM in range(2, 5):
             parse_latex(r"""
-                % vardef -metric gUU::{DIM}D
+                % define gUU --dim {DIM} --metric
+                % index [a-c] --dim {DIM}
                 \Delta^a_c = g^{{ab}} g_{{bc}}
             """.format(DIM=DIM))
             for i in range(DIM):
